package com.persagy.account.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.google.common.collect.Lists;
import com.persagy.account.pojo.dto.SaasProductCategeory;
import com.persagy.account.pojo.vo.product.SaasProductCategeoryQueryVO;
import com.persagy.account.service.ISaasProductCategeoryService;
import com.persagy.common.utils.ResponseResult;
import com.persagy.common.utils.ResponseResultUtil;

import cn.hutool.core.collection.CollectionUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 产品信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-05-11 19:23:03
 */

@Api(tags = "产品类别信息")
@RestController
@RequestMapping(value = "/productCategeory", method = RequestMethod.POST)
public class SaasProductCategeoryController {
	
    @Autowired
    private ISaasProductCategeoryService saasProductCategeoryService;
    
    /**
     * 列表查询
     */
    @ApiOperation(value = "产品类别树查询")
    @RequestMapping(value = "querySaasProductCategeoryTree")
    public ResponseResult querySaasProductCategeoryTree(@RequestBody @Validated SaasProductCategeoryQueryVO model) {
    	LambdaQueryWrapper<SaasProductCategeory> queryWrapper = new SaasProductCategeory.BuilderQueryWrapper()
    			.categoryNameLike(model.getCategoryName()).idEq(model.getId()).menuTypeEq(model.getMenuType())
    			.productTypeEq(model.getProductType()).terminalEq(model.getTerminal()).builder();
    	queryWrapper.apply("(PARENT_ID IS NULL OR TRIM(PARENT_ID) = '')");
    	List<SaasProductCategeory> topList = this.saasProductCategeoryService.list(queryWrapper.orderByAsc(SaasProductCategeory::getCreateTime));
    	if (CollectionUtil.isEmpty(topList)) {
			return ResponseResultUtil.successResult(Lists.newArrayList());
		}
    	this.querySaasProductCategeoryTree(topList);
        return ResponseResultUtil.successResult(topList);
    }
    
    /**
     * 获取产品类别树
     * @param list
     */
    private void querySaasProductCategeoryTree(List<SaasProductCategeory> list) {
		for (SaasProductCategeory categeory : list) {
			LambdaQueryWrapper<SaasProductCategeory> queryWrapper = new SaasProductCategeory.BuilderQueryWrapper().parentIdEq(categeory.getId()).builder();
	    	List<SaasProductCategeory> nextList = this.saasProductCategeoryService.list(queryWrapper.orderByAsc(SaasProductCategeory::getCreateTime));
	    	nextList = CollectionUtil.isEmpty(nextList) ? Lists.newArrayList() : nextList;
	    	categeory.setChildrens(nextList);
			this.querySaasProductCategeoryTree(nextList);
		}
	}

    /**
     * 新增
     */
	@ApiOperation(value = "保存")
	@RequestMapping(value = "createSaasProductCategeory")
    public ResponseResult createSaasProductCategeory(@RequestBody SaasProductCategeory saasProductCategeory) {
        boolean result = this.saasProductCategeoryService.save(saasProductCategeory);
        return result ? ResponseResultUtil.successResult("保存成功", saasProductCategeory.getId()) : ResponseResultUtil.errorResult("保存失败");
    }
    
    /**
     * 更新
     */
	@ApiOperation(value = "更新")
	@RequestMapping(value = "updateSaasProductCategeory")
    public ResponseResult updateSaasProductCategeory(@RequestBody SaasProductCategeory saasProductCategeory) {
        boolean result = this.saasProductCategeoryService.updateById(saasProductCategeory);
        return result ? ResponseResultUtil.successResult("更新成功") : ResponseResultUtil.errorResult("更新失败");
    }

    /**
     * 物理删除
     */
    @ApiOperation(value = "删除")
    @RequestMapping(value = "deleteSaasProductCategeory")
    public ResponseResult deleteSaasProductCategeory(@RequestBody SaasProductCategeory saasProductCategeory) {
        boolean result = this.saasProductCategeoryService.removeById(saasProductCategeory.getId());
        return result ? ResponseResultUtil.successResult("删除成功") : ResponseResultUtil.errorResult("删除失败");
    }
    
}
