package com.persagy.account.pojo.dto;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.persagy.common.annotation.IdGeneratorPrefix;
import com.persagy.common.constant.SaasCommonConstant;
import com.persagy.common.model.BaseEntity;
import com.persagy.common.utils.StringUtil;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 产品信息
 * 
 * @version 1.0.0
 * @company persagy
 * @author zhangqiankun
 * @date 2021-05-11 19:23:03
 */
@Getter
@Setter
@ToString
@EqualsAndHashCode(callSuper = false)
@TableName("saas_product_categeory")
@IdGeneratorPrefix(SaasCommonConstant.SAAS_PRODUCT_CATEGEORY_ID_PREFIX)
public class SaasProductCategeory extends BaseEntity<SaasProductCategeory> {
	private static final long serialVersionUID = 8965388764057710104L;

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String parentId; // 上级ID

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String categoryName; // 类别名称

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String categoryIcon; // 类别图标

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String terminal; // 类别所属终端

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String terminalName; // 类别所属终端名称

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String productType; // 此类别所对应的产品类型

	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String menuType; // 此类别所对应的菜单类型
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private Date createTime;	// 创建时间
	
	@TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
	private String remark;	// 备注
	
	@TableField(exist = false)
	private List<SaasProductCategeory> childrens;	//资料

	public static class BuilderQueryWrapper {

		private LambdaQueryWrapper<SaasProductCategeory> queryWrapper = new LambdaQueryWrapper<SaasProductCategeory>();

		public BuilderQueryWrapper idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				queryWrapper.eq(SaasProductCategeory::getId, id);
			}
			return this;
		}

		public BuilderQueryWrapper parentIdEq(String parentId) {
			if (StringUtil.isNotBlank(parentId)) {
				queryWrapper.eq(SaasProductCategeory::getParentId, parentId);
			}
			return this;
		}

		public BuilderQueryWrapper categoryNameEq(String categoryName) {
			if (StringUtil.isNotBlank(categoryName)) {
				queryWrapper.eq(SaasProductCategeory::getCategoryName, categoryName);
			}
			return this;
		}
		
		public BuilderQueryWrapper categoryNameLike(String categoryName) {
			if (StringUtil.isNotBlank(categoryName)) {
				queryWrapper.like(SaasProductCategeory::getCategoryName, categoryName);
			}
			return this;
		}

		public BuilderQueryWrapper categoryIconEq(String categoryIcon) {
			if (StringUtil.isNotBlank(categoryIcon)) {
				queryWrapper.eq(SaasProductCategeory::getCategoryIcon, categoryIcon);
			}
			return this;
		}

		public BuilderQueryWrapper terminalEq(String terminal) {
			if (StringUtil.isNotBlank(terminal)) {
				queryWrapper.eq(SaasProductCategeory::getTerminal, terminal);
			}
			return this;
		}

		public BuilderQueryWrapper terminalNameEq(String terminalName) {
			if (StringUtil.isNotBlank(terminalName)) {
				queryWrapper.eq(SaasProductCategeory::getTerminalName, terminalName);
			}
			return this;
		}

		public BuilderQueryWrapper productTypeEq(String productType) {
			if (StringUtil.isNotBlank(productType)) {
				queryWrapper.eq(SaasProductCategeory::getProductType, productType);
			}
			return this;
		}

		public BuilderQueryWrapper menuTypeEq(String menuType) {
			if (StringUtil.isNotBlank(menuType)) {
				queryWrapper.eq(SaasProductCategeory::getMenuType, menuType);
			}
			return this;
		}

		public LambdaQueryWrapper<SaasProductCategeory> builder() {
			return queryWrapper;
		}

	}

	public static class BuilderUpdateWrapper {

		private LambdaUpdateWrapper<SaasProductCategeory> updateWrapper = new LambdaUpdateWrapper<SaasProductCategeory>();

		public BuilderUpdateWrapper idEq(String id) {
			if (StringUtil.isNotBlank(id)) {
				updateWrapper.eq(SaasProductCategeory::getId, id);
			}
			return this;
		}

		public BuilderUpdateWrapper parentIdEq(String parentId) {
			if (StringUtil.isNotBlank(parentId)) {
				updateWrapper.eq(SaasProductCategeory::getParentId, parentId);
			}
			return this;
		}

		public BuilderUpdateWrapper categoryNameEq(String categoryName) {
			if (StringUtil.isNotBlank(categoryName)) {
				updateWrapper.eq(SaasProductCategeory::getCategoryName, categoryName);
			}
			return this;
		}

		public BuilderUpdateWrapper categoryIconEq(String categoryIcon) {
			if (StringUtil.isNotBlank(categoryIcon)) {
				updateWrapper.eq(SaasProductCategeory::getCategoryIcon, categoryIcon);
			}
			return this;
		}

		public BuilderUpdateWrapper terminalEq(String terminal) {
			if (StringUtil.isNotBlank(terminal)) {
				updateWrapper.eq(SaasProductCategeory::getTerminal, terminal);
			}
			return this;
		}

		public BuilderUpdateWrapper terminalNameEq(String terminalName) {
			if (StringUtil.isNotBlank(terminalName)) {
				updateWrapper.eq(SaasProductCategeory::getTerminalName, terminalName);
			}
			return this;
		}

		public BuilderUpdateWrapper productTypeEq(String productType) {
			if (StringUtil.isNotBlank(productType)) {
				updateWrapper.eq(SaasProductCategeory::getProductType, productType);
			}
			return this;
		}

		public BuilderUpdateWrapper menuTypeEq(String menuType) {
			if (StringUtil.isNotBlank(menuType)) {
				updateWrapper.eq(SaasProductCategeory::getMenuType, menuType);
			}
			return this;
		}

		public LambdaUpdateWrapper<SaasProductCategeory> builder() {
			return updateWrapper;
		}

	}
	
}
